@@ -1,6 +1,6 @@
 import json
 import requests
-import dk_api_helpers
+import datakitchen_api_tools.dk_api_helpers as dk_api_helpers
 
 class DKConnection():
     def __init__(self, hostname, username, password):
